@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Box::Identity;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base qw/User::Identity::Item Mail::Reporter/;
 
@@ -199,13 +199,7 @@ sub folder(@)
 
 sub open(@)
 {   my $self = shift;
-    my $mgr  = $self->manager;
-
-    $mgr->open
-      ( $self->fullname
-      , type => $self->folderType
-      , @_
-      );
+    $self->manager->open($self->fullname, type => $self->folderType, @_);
 }
 
 #-------------------------------------------
