@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Box::Manager;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base 'Mail::Reporter';
 
@@ -136,7 +136,7 @@ sub open(@)
     $name    = defined $args{folder} ? $args{folder} : ($ENV{MAIL} || '')
         unless defined $name;
 
-    if($name =~ m/^(\w+)\:/ && grep { $_ eq $1 } $self->folderTypes)
+    if($name =~ m/^(\w+)\:/ && grep $_ eq $1, $self->folderTypes)
     {   # Complicated folder URL
         my %decoded = $self->decodeFolderURL($name);
         if(keys %decoded)
