@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Box::Parser::Perl;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base 'Mail::Box::Parser';
 
@@ -184,6 +184,9 @@ sub _read_stripped_lines(;$$)
         }
         unless($self->{MBPP_trusted})
         {   s/\015$// for @$lines;
+            # input is read as binary stream (i.e. preserving CRLF on Windows).
+            # Code is based on this assumption. Removal of CR if not trusted
+            # conflicts with this assumption. [Markus Spann]
         }
     }
 #warn "($bodyend, $msgend, ".@$lines, ")\n";
@@ -270,7 +273,7 @@ sub openFile($)
     $self->{MBPP_file}       = $fh;
 
     $fh->binmode(':raw')
-        if ref($fh) eq 'GLOB' || $fh->can('BINMODE');
+        if $fh->can('binmode') || $fh->can('BINMODE');
 
     $self->{MBPP_separators} = [];
 
