@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base 'Mail::Reporter';
 
@@ -21,7 +21,6 @@ use Mail::Message::Body::Nested;
 
 use Carp;
 use Scalar::Util   'weaken';
-use Devel::GlobalDestruction 'in_global_destruction';
 
 
 our $crlf_platform;
@@ -688,16 +687,6 @@ sub shortString()
 #------------------------------------------
 
 
-sub DESTROY()
-{   my $self = shift;
-    return if in_global_destruction;
-
-    $self->SUPER::DESTROY;
-    $self->head(undef);
-    $self->body(undef);
-}
-
-
 sub destruct() { $_[0] = undef }
 
 #------------------------------------------
