@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base 'Mail::Reporter';
 
@@ -202,8 +202,9 @@ sub eol(;$)
 sub message(;$)
 {   my $self = shift;
     if(@_)
-    {   $self->{MMB_message} = shift;
-        weaken($self->{MMB_message});
+    {   if($self->{MMB_message} = shift)
+        {   weaken $self->{MMB_message};
+        }
     }
     $self->{MMB_message};
 }
