@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Field::AddrGroup;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base 'User::Identity::Collection::Emails';
 
@@ -20,7 +20,7 @@ use overload '""' => 'string';
 sub string()
 {   my $self = shift;
     my $name = $self->name;
-    my @addr = sort map {$_->string} $self->addresses;
+    my @addr = sort map $_->string, $self->addresses;
 
     local $" = ', ';
 
