@@ -7,7 +7,7 @@ use strict;
 
 package Mail::Message::Head::Partial;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.117';
 
 use base 'Mail::Message::Head::Complete';
 
@@ -21,16 +21,13 @@ sub removeFields(@)
     foreach my $match (@_)
     {
         if(ref $match)
-        {   $_ =~ $match && delete $known->{$_} foreach keys %$known;
-        }
+             { $_ =~ $match && delete $known->{$_} foreach keys %$known }
         else { delete $known->{lc $match} }
     }
 
     $self->cleanupOrderedFields;
 }
 
-#------------------------------------------
-
 
 sub removeFieldsExcept(@)
 {   my $self   = shift;
